Contributing to rabbitmq-c
==========================

Thanks for contributing to rabbitmq-c. I firmly believe that participation helps
make open source software great. With that there are a few things that can be
done to make our interaction a bit smoother.

Please use the following guidelines when creating an issue or submitting a 
pull request

Creating an issue
-----------------
When submitting an issue its helpful to know the following
 - What version of rabbitmq-c are you using?
 - What operating system and version are you running on?
 - What compiler and version are you running?
 -
 - If its a build system issue: which build system are you using (


Submitting a pull-request
-------------------------
I love to get code contributions, a few things that can help out:
 - Make sure your commits are rebased on the current master branch
 - Please collapse your commits down to a couple logical commits

